DCache

Struct DCache 

pub struct DCache<const CHUNK_COUNT: usize, const CHUNK_SIZE: usize> { /* private fields */ }

Implementations

Source

impl<const CHUNK_COUNT: usize, const CHUNK_SIZE: usize> DCache<CHUNK_COUNT, CHUNK_SIZE>

pub fn new() -> Self

Create a fixed-size cache of payload chunks.

CHUNK_COUNT must be a power of two.

pub fn allocate(&self) -> u32

Allocate a chunk index for a new payload (ring buffer style).

This wraps around, so callers must use flow control (Fctl) to ensure chunks are not overwritten before consumers are done with them.

pub fn capacity(&self) -> usize

Returns the number of chunks in the cache.

pub fn write_chunk( &self, chunk: u32, payload: &[u8], ) -> Result<usize, TangoError>

Write payload bytes into a chunk, truncating to the chunk size.

pub fn read_chunk( &self, chunk: u32, size: usize, ) -> Result<DcacheView<'_, CHUNK_SIZE>, TangoError>

Read a view of a chunk with the provided size limit.

pub fn chunk_size(&self) -> usize

Return the configured chunk size in bytes.