pub struct MCache<const DEPTH: usize> { /* private fields */ }Implementations
Sourceimpl<const DEPTH: usize> MCache<DEPTH>
impl<const DEPTH: usize> MCache<DEPTH>
pub fn stop(&self)
pub fn is_running(&self) -> bool
Sourcepub fn publish(&self, meta: FragmentMetadata)
pub fn publish(&self, meta: FragmentMetadata)
Publish a fragment’s metadata into the ring.
Sourcepub fn wait(&self, seq: u64) -> ReadResult<FragmentMetadata>
pub fn wait(&self, seq: u64) -> ReadResult<FragmentMetadata>
Busy-wait for a specific sequence number to appear.
Returns:
ReadResult::Ok(meta)if the sequence was successfully readReadResult::Overrunif the consumer was lapped by the producerReadResult::NotReadyif the mcache was stopped before the sequence appeared
Sourcepub fn try_read(&self, seq: u64) -> ReadResult<FragmentMetadata>
pub fn try_read(&self, seq: u64) -> ReadResult<FragmentMetadata>
Attempt a lock-free read of the metadata at a specific sequence.
Returns:
ReadResult::Ok(meta)if the sequence was successfully readReadResult::NotReadyif the sequence has not been published yetReadResult::Overrunif the consumer was lapped by the producer